@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2019-2022, by Samuel Williams.
+# Copyright, 2019-2023, by Samuel Williams.
 
 require_relative 'filter'
 
@@ -55,6 +55,10 @@ module Console
 				message[:arguments] = arguments
 			end
 			
+			if annotation = Fiber.current.annotation
+				message[:annotation] = annotation
+			end
+			
 			if block_given?
 				if block.arity.zero?
 					message[:message] = yield
